# mpl-point-clicker

A multiclass point clicker for matplotlib

![GIF of example usage](docs/_static/images/front-page.apng)


Read the [Documentation](https://mpl-point-clicker.readthedocs.io/en/stable)

## Installation

You can install using `pip`:

```bash
pip install mpl_point_clicker
```

## Development Installation


```bash
pip install -e ".[dev]"
```

